@@ -3,7 +3,7 @@ use strict;
 use Acme::MetaSyntactic::MultiList;
 use Acme::MorningMusume;
 our @ISA     = qw( Acme::MetaSyntactic::MultiList );
-our $VERSION = '1.000';
+our $VERSION = '1.001';
 
 	my $musume = Acme::MorningMusume->new;
 	#my @all      = map { $_->name_en } $musume->members;
@@ -23,15 +23,35 @@ __PACKAGE__->init(
 
 =head1 NAME
 
-Acme::MetaSyntactic::morning_musume
+Acme::MetaSyntactic::morning_musume -- The theme of Morning Musume
 
 =head1 DESCRIPTION
 
-Think about around Morning Musume
+The names (english transcription) of the Japanese Pop Idols Morning Musume
+
+The list is provided by the module Acme::MorningMusume from KENTARO
+
+Two themes are available: active (default), graduate
+
+=head1 INSTALL
+
+To install this module, run the following commands:
+
+    perl Build.PL
+    ./Build
+    ./Build test
+    ./Build install
+
+Alternatively, to install with ExtUtils::MakeMaker, you can use the following commands:
+
+    perl Makefile.PL
+    make
+    make test
+    make install
 
 =head1 CONTRIBUTOR
 
-Laurent Boivin
+Laurent Boivin (elbeho)
 
 =head1 CHANGES
 
@@ -39,9 +59,15 @@ Laurent Boivin
 
 =item *
 
+2012-10-17 - v1.001
+
+Fix documentation (pod and readme)
+
+=item *
+
 2012-10-13 - v1.000
 
-First attempt... don't be rude. Gomen nasai.
+First version of my first module
 
 =back
 
@@ -50,6 +76,10 @@ First attempt... don't be rude. Gomen nasai.
 L<Acme::MorningMusume>,
 L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.
 
+=head1 COPYRIGHT
+
+Copyright (C) 2012 Laurent Boivin (elbeho)
+
 =head1 LICENSE
 
 This program is free software; you can redistribute it and/or modify it
@@ -57,4 +87,3 @@ under the same terms as Perl itself.
 
 =cut
 
-
